@@ -1,13 +1,16 @@
 <?php
 
+declare(strict_types=1);
+
 namespace GuzzleHttp\Tests\Psr7;
 
 use GuzzleHttp\Psr7\BufferStream;
 use GuzzleHttp\Psr7\DroppingStream;
+use PHPUnit\Framework\TestCase;
 
-class DroppingStreamTest extends BaseTest
+class DroppingStreamTest extends TestCase
 {
-    public function testBeginsDroppingWhenSizeExceeded()
+    public function testBeginsDroppingWhenSizeExceeded(): void
     {
         $stream = new BufferStream();
         $drop = new DroppingStream($stream, 5);
